@@ -59,8 +59,12 @@ class PrimeNumbers(object):
     def __init__(self, startat1 = False) -> None:
         """
         startat1 = False (default) will yield 2,3,5,...
+        This also means primes[0] == 2; primes[3] == 7 : zero-based indexing for primes[n]
         
         startat1 = True will yield 1, 2, 3, 5, ...
+        This also means primes[1] == 2; primes[3] == 5 : 1-based indexing for primes[n]
+
+        Recommend using startat1 = False in context 'for prime in primes', startat1 = True when looking up the n-th prime 'primes[n]'
 
         PrimeNumbers.preseed(n) will pre-calculate all primes < n using sieve for faster access at cost of slower initiation.
         Do this if you are sure you actually need that many primes
@@ -108,6 +112,40 @@ class PrimeNumbers(object):
                 elif p*p > __o:
                     return True
 
+    def __getitem__(self, key):
+        cls = self.__class__
+        
+        try:
+            start, stop, step = key.start, key.stop, key.step
+        except AttributeError:
+            start, stop, step = key, key + 1, 1
+            slicewanted = False
+        else:
+            slicewanted = True
+        
+        if start < 0 or stop < 0:
+            raise ValueError("Cannot use negative indexing on an infinite series")
+
+        if step is not None and step < 0:
+            reverse = True
+            raise NotImplementedError("Negative Step coming soon...")
+        else:
+            reverse = False
+
+        if not self._startat1:
+            start, stop = start + 1, stop + 1
+
+        if stop > len(cls._knownprimes):
+            primes = PrimeNumbers()
+            while len(cls._knownprimes) < stop:
+                next(primes)
+        
+        if slicewanted:
+            return cls._knownprimes[start:stop:step]
+        else:
+            return cls._knownprimes[start]
+
+
     @classmethod
     def _generateprimes(cls):
         #calculates potential primes using n = ak + j where:
